jactorch.transforms.bbox.functional
===================================

.. automodule:: jactorch.transforms.bbox.functional

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      center_crop
      crop
      denormalize_bbox
      hflip
      normalize_bbox
      pad
      pad_multiple_of
      resize
      resized_crop
      rotate
      vflip
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: center_crop

.. autofunction:: crop

.. autofunction:: denormalize_bbox

.. autofunction:: hflip

.. autofunction:: normalize_bbox

.. autofunction:: pad

.. autofunction:: pad_multiple_of

.. autofunction:: resize

.. autofunction:: resized_crop

.. autofunction:: rotate

.. autofunction:: vflip


